@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -22,6 +22,9 @@
  * $tz->getZone('America/New_York')->toVtimezone()->exportVcalendar();
  * </code>
  *
+ * Documentation on the database file formats can be found at
+ * ftp://ftp.iana.org/tz/tz-how-to.html
+ *
  * @author  Jan Schneider <jan@horde.org>
  * @package Timezone
  */
@@ -199,6 +202,7 @@ class Horde_Timezone
             }
         } else {
             $this->_tmpfile = $this->_params['location'];
+            unset($php_errormsg);
             if (!is_readable($this->_tmpfile)) {
                 $e = new Horde_Timezone_Exception(sprintf('Unable to open file %s.', $this->_params['location']));
                 if (isset($php_errormsg)) {
